<!--

@license Apache-2.0

Copyright (c) 2022 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->

# thunk

> Generate a [thunk][thunk].

<!-- Section to include introductory text. Make sure to keep an empty line after the intro `section` element and another before the `/section` close. -->

<section class="intro">

</section>

<!-- /.intro -->

<!-- Package usage documentation. -->

<section class="usage">

## Usage

```javascript
var thunk = require( '@stdlib/utils/thunk' );
```

#### thunk( fcn\[, ...args] )

Returns a [thunk][thunk] (i.e., an anonymous function having arity `0` and which invokes a provided function with specified arguments).

```javascript
var add = require( '@stdlib/math/base/ops/add' );

var f = thunk( add, 2.0, 3.0 );
// returns <Function>

var v = f();
// returns 5

// ...

v = f();
// returns 5
```

</section>

<!-- /.usage -->

<!-- Package usage notes. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="notes">

</section>

<!-- /.notes -->

<!-- Package usage examples. -->

<section class="examples">

## Examples

<!-- eslint no-undef: "error" -->

```javascript
var add = require( '@stdlib/math/base/ops/add' );
var decorateAfter = require( '@stdlib/utils/decorate-after' );
var discreteUniform = require( '@stdlib/random/base/discrete-uniform' ).factory;
var thunk = require( '@stdlib/utils/thunk' );

function log( v ) {
    console.log( v );
}

// Create a PRNG for generating uniformly distributed pseudorandom integers:
var randi = discreteUniform( 100, 1000 );

// Randomly delay evaluation of various thunks...
var i;
for ( i = 0; i < 10; i++ ) {
    setTimeout( decorateAfter( thunk( add, i, i+1 ), 0, log ), randi() );
}
```

</section>

<!-- /.examples -->

<!-- Section to include cited references. If references are included, add a horizontal rule *before* the section. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="references">

</section>

<!-- /.references -->

<!-- Section for related `stdlib` packages. Do not manually edit this section, as it is automatically populated. -->

<section class="related">

</section>

<!-- /.related -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

[thunk]: https://en.wikipedia.org/wiki/Thunk

<!-- <related-links> -->

<!-- </related-links> -->

</section>

<!-- /.links -->
